==> estateplat-common-1.2.3-20180516.134834-89-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtJk.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;


/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    商品房价款历史表(第三章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_jk")
public class FcjyXjspfBaMmhtJk {
    @Id
    private String jklsid;//主键
    private String htlsid;//合同历史表id
    private String jkid;//商品房价款(第三章)主键
    private String htid;//合同ID
    private String jklx;//价款类型
    private String atzjkbz;//按套总价款币种(币种字典表)
    private String atnmjpfmbz;//按套内面积每平方米币种(币种字典表)
    private Double atzje;//按套总金额
    private Double atnmjpfje;//按套内面积每平方金额
    private Double atnmjzje;//按套内面积总金额
    private Double ajzmjpfje;//按建筑面积每平方金额
    private Double ajzmjzje;//按建筑面积总金额
    private String aqtnr;//按其他内容
    private Double aqtnrpfje;//按其他内容每平方金额
    private Double aqtnrzje;//按其他内容总金额
    private String zfdjbz;//支付定金币种(币种字典表)
    private Double zfdjje;//支付定金金额
    private String djyxx;//定金于XX
    private String xxspfjk;//XX商品房价款
    private String fklx;//付款类型
    private Date ycxfkjzrq;//一次性付款截止日期
    private Date fqfkjzrq;//分期付款截止日期
    private Integer fqfkqs;//分期付款期数
    private String sqfjkbz;//首期房价款币种(币种字典表)
    private Double fqsqfjk;//分期首期房价款
    private Date fqsqfjkjzrq;//分期首期房价款截止日期
    private String dkfs;//贷款方式(贷款方式字典表)
    private Double dksqfjk;//贷款首期房价款
    private Double dksqfjkzb;//贷款首期房价款占比(百分之)
    private String ykbz;//余款币种(币种字典表)
    private Double ykje;//余款金额
    private String fkqtfs;//付款其他方式
    private String yqclfs;//逾期处理方式
    private Integer yqxxrn;//逾期XX日内
    private Double yqxrnwfzxwyj;//逾期X日内万分之X违约金(万分之)
    private Integer yqcxxr;//逾期超XX日
    private Integer jchthtsdrqxxr;//解除合同合同送达日起XX日
    private Double ljyfkxxbfb;//累计应付款XX百分比
    private Double jchtwfzxwyj;//解除合同万分之X违约金(万分之)
    private String yqqtfs;//逾期其他方式
    private String aqtnrzjkbz;//按其他内容总价款币种(币种字典表)
    private String ajzmjzjkbz;//按建筑面积总价款币种(币种字典表)
    private String ajzmjpfmbz;//按建筑面积每平方米币种(币种字典表)
    private String atnmjzjkbz;//按套内面积总价款币种(币种字典表)
    private Date dksqfjzrq;//贷款首期房截止日期
    private String dksqfjkbz;//贷款首期房价款币种(币种字典表)
    private String khyh;//开户银行
    private String yhzhm;//银行账户名
    private String yhzh;//银行账号
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getJklsid() {
        return jklsid;
    }

    public void setJklsid(String jklsid) {
        this.jklsid = jklsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getJkid() {
        return jkid;
    }

    public void setJkid(String jkid) {
        this.jkid = jkid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJklx() {
        return jklx;
    }

    public void setJklx(String jklx) {
        this.jklx = jklx;
    }

    public String getAtzjkbz() {
        return atzjkbz;
    }

    public void setAtzjkbz(String atzjkbz) {
        this.atzjkbz = atzjkbz;
    }

    public String getAtnmjpfmbz() {
        return atnmjpfmbz;
    }

    public void setAtnmjpfmbz(String atnmjpfmbz) {
        this.atnmjpfmbz = atnmjpfmbz;
    }

    public Double getAtzje() {
        return atzje;
    }

    public void setAtzje(Double atzje) {
        this.atzje = atzje;
    }

    public Double getAtnmjpfje() {
        return atnmjpfje;
    }

    public void setAtnmjpfje(Double atnmjpfje) {
        this.atnmjpfje = atnmjpfje;
    }

    public Double getAtnmjzje() {
        return atnmjzje;
    }

    public void setAtnmjzje(Double atnmjzje) {
        this.atnmjzje = atnmjzje;
    }

    public Double getAjzmjpfje() {
        return ajzmjpfje;
    }

    public void setAjzmjpfje(Double ajzmjpfje) {
        this.ajzmjpfje = ajzmjpfje;
    }

    public Double getAjzmjzje() {
        return ajzmjzje;
    }

    public void setAjzmjzje(Double ajzmjzje) {
        this.ajzmjzje = ajzmjzje;
    }

    public String getAqtnr() {
        return aqtnr;
    }

    public void setAqtnr(String aqtnr) {
        this.aqtnr = aqtnr;
    }

    public Double getAqtnrpfje() {
        return aqtnrpfje;
    }

    public void setAqtnrpfje(Double aqtnrpfje) {
        this.aqtnrpfje = aqtnrpfje;
    }

    public Double getAqtnrzje() {
        return aqtnrzje;
    }

    public void setAqtnrzje(Double aqtnrzje) {
        this.aqtnrzje = aqtnrzje;
    }

    public String getZfdjbz() {
        return zfdjbz;
    }

    public void setZfdjbz(String zfdjbz) {
        this.zfdjbz = zfdjbz;
    }

    public Double getZfdjje() {
        return zfdjje;
    }

    public void setZfdjje(Double zfdjje) {
        this.zfdjje = zfdjje;
    }

    public String getDjyxx() {
        return djyxx;
    }

    public void setDjyxx(String djyxx) {
        this.djyxx = djyxx;
    }

    public String getXxspfjk() {
        return xxspfjk;
    }

    public void setXxspfjk(String xxspfjk) {
        this.xxspfjk = xxspfjk;
    }

    public String getFklx() {
        return fklx;
    }

    public void setFklx(String fklx) {
        this.fklx = fklx;
    }

    public Date getYcxfkjzrq() {
        return ycxfkjzrq;
    }

    public void setYcxfkjzrq(Date ycxfkjzrq) {
        this.ycxfkjzrq = ycxfkjzrq;
    }

    public Date getFqfkjzrq() {
        return fqfkjzrq;
    }

    public void setFqfkjzrq(Date fqfkjzrq) {
        this.fqfkjzrq = fqfkjzrq;
    }

    public Integer getFqfkqs() {
        return fqfkqs;
    }

    public void setFqfkqs(Integer fqfkqs) {
        this.fqfkqs = fqfkqs;
    }

    public String getSqfjkbz() {
        return sqfjkbz;
    }

    public void setSqfjkbz(String sqfjkbz) {
        this.sqfjkbz = sqfjkbz;
    }

    public Double getFqsqfjk() {
        return fqsqfjk;
    }

    public void setFqsqfjk(Double fqsqfjk) {
        this.fqsqfjk = fqsqfjk;
    }

    public Date getFqsqfjkjzrq() {
        return fqsqfjkjzrq;
    }

    public void setFqsqfjkjzrq(Date fqsqfjkjzrq) {
        this.fqsqfjkjzrq = fqsqfjkjzrq;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Double getDksqfjk() {
        return dksqfjk;
    }

    public void setDksqfjk(Double dksqfjk) {
        this.dksqfjk = dksqfjk;
    }

    public Double getDksqfjkzb() {
        return dksqfjkzb;
    }

    public void setDksqfjkzb(Double dksqfjkzb) {
        this.dksqfjkzb = dksqfjkzb;
    }

    public String getYkbz() {
        return ykbz;
    }

    public void setYkbz(String ykbz) {
        this.ykbz = ykbz;
    }

    public Double getYkje() {
        return ykje;
    }

    public void setYkje(Double ykje) {
        this.ykje = ykje;
    }

    public String getFkqtfs() {
        return fkqtfs;
    }

    public void setFkqtfs(String fkqtfs) {
        this.fkqtfs = fkqtfs;
    }

    public String getYqclfs() {
        return yqclfs;
    }

    public void setYqclfs(String yqclfs) {
        this.yqclfs = yqclfs;
    }

    public Integer getYqxxrn() {
        return yqxxrn;
    }

    public void setYqxxrn(Integer yqxxrn) {
        this.yqxxrn = yqxxrn;
    }

    public Double getYqxrnwfzxwyj() {
        return yqxrnwfzxwyj;
    }

    public void setYqxrnwfzxwyj(Double yqxrnwfzxwyj) {
        this.yqxrnwfzxwyj = yqxrnwfzxwyj;
    }

    public Integer getYqcxxr() {
        return yqcxxr;
    }

    public void setYqcxxr(Integer yqcxxr) {
        this.yqcxxr = yqcxxr;
    }

    public Integer getJchthtsdrqxxr() {
        return jchthtsdrqxxr;
    }

    public void setJchthtsdrqxxr(Integer jchthtsdrqxxr) {
        this.jchthtsdrqxxr = jchthtsdrqxxr;
    }

    public Double getLjyfkxxbfb() {
        return ljyfkxxbfb;
    }

    public void setLjyfkxxbfb(Double ljyfkxxbfb) {
        this.ljyfkxxbfb = ljyfkxxbfb;
    }

    public Double getJchtwfzxwyj() {
        return jchtwfzxwyj;
    }

    public void setJchtwfzxwyj(Double jchtwfzxwyj) {
        this.jchtwfzxwyj = jchtwfzxwyj;
    }

    public String getYqqtfs() {
        return yqqtfs;
    }

    public void setYqqtfs(String yqqtfs) {
        this.yqqtfs = yqqtfs;
    }

    public String getAqtnrzjkbz() {
        return aqtnrzjkbz;
    }

    public void setAqtnrzjkbz(String aqtnrzjkbz) {
        this.aqtnrzjkbz = aqtnrzjkbz;
    }

    public String getAjzmjzjkbz() {
        return ajzmjzjkbz;
    }

    public void setAjzmjzjkbz(String ajzmjzjkbz) {
        this.ajzmjzjkbz = ajzmjzjkbz;
    }

    public String getAjzmjpfmbz() {
        return ajzmjpfmbz;
    }

    public void setAjzmjpfmbz(String ajzmjpfmbz) {
        this.ajzmjpfmbz = ajzmjpfmbz;
    }

    public String getAtnmjzjkbz() {
        return atnmjzjkbz;
    }

    public void setAtnmjzjkbz(String atnmjzjkbz) {
        this.atnmjzjkbz = atnmjzjkbz;
    }

    public Date getDksqfjzrq() {
        return dksqfjzrq;
    }

    public void setDksqfjzrq(Date dksqfjzrq) {
        this.dksqfjzrq = dksqfjzrq;
    }

    public String getDksqfjkbz() {
        return dksqfjkbz;
    }

    public void setDksqfjkbz(String dksqfjkbz) {
        this.dksqfjkbz = dksqfjkbz;
    }

    public String getKhyh() {
        return khyh;
    }

    public void setKhyh(String khyh) {
        this.khyh = khyh;
    }

    public String getYhzhm() {
        return yhzhm;
    }

    public void setYhzhm(String yhzhm) {
        this.yhzhm = yhzhm;
    }

    public String getYhzh() {
        return yhzh;
    }

    public void setYhzh(String yhzh) {
        this.yhzh = yhzh;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180612.084136-114-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtJk.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;


/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    商品房价款历史表(第三章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_jk")
public class FcjyXjspfBaMmhtJk implements Serializable {
    @Id
    private String jklsid;//主键
    private String htlsid;//合同历史表id
    private String jkid;//商品房价款(第三章)主键
    private String htid;//合同ID
    private String jklx;//价款类型
    private String atzjkbz;//按套总价款币种(币种字典表)
    private String atnmjpfmbz;//按套内面积每平方米币种(币种字典表)
    private Double atzje;//按套总金额
    private Double atnmjpfje;//按套内面积每平方金额
    private Double atnmjzje;//按套内面积总金额
    private Double ajzmjpfje;//按建筑面积每平方金额
    private Double ajzmjzje;//按建筑面积总金额
    private String aqtnr;//按其他内容
    private Double aqtnrpfje;//按其他内容每平方金额
    private Double aqtnrzje;//按其他内容总金额
    private String zfdjbz;//支付定金币种(币种字典表)
    private Double zfdjje;//支付定金金额
    private String djyxx;//定金于XX
    private String xxspfjk;//XX商品房价款
    private String fklx;//付款类型
    private Date ycxfkjzrq;//一次性付款截止日期
    private Date fqfkjzrq;//分期付款截止日期
    private Integer fqfkqs;//分期付款期数
    private String sqfjkbz;//首期房价款币种(币种字典表)
    private Double fqsqfjk;//分期首期房价款
    private Date fqsqfjkjzrq;//分期首期房价款截止日期
    private String dkfs;//贷款方式(贷款方式字典表)
    private Double dksqfjk;//贷款首期房价款
    private Double dksqfjkzb;//贷款首期房价款占比(百分之)
    private String ykbz;//余款币种(币种字典表)
    private Double ykje;//余款金额
    private String fkqtfs;//付款其他方式
    private String yqclfs;//逾期处理方式
    private Integer yqxxrn;//逾期XX日内
    private Double yqxrnwfzxwyj;//逾期X日内万分之X违约金(万分之)
    private Integer yqcxxr;//逾期超XX日
    private Integer jchthtsdrqxxr;//解除合同合同送达日起XX日
    private Double ljyfkxxbfb;//累计应付款XX百分比
    private Double jchtwfzxwyj;//解除合同万分之X违约金(万分之)
    private String yqqtfs;//逾期其他方式
    private String aqtnrzjkbz;//按其他内容总价款币种(币种字典表)
    private String ajzmjzjkbz;//按建筑面积总价款币种(币种字典表)
    private String ajzmjpfmbz;//按建筑面积每平方米币种(币种字典表)
    private String atnmjzjkbz;//按套内面积总价款币种(币种字典表)
    private Date dksqfjzrq;//贷款首期房截止日期
    private String dksqfjkbz;//贷款首期房价款币种(币种字典表)
    private String khyh;//开户银行
    private String yhzhm;//银行账户名
    private String yhzh;//银行账号
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getJklsid() {
        return jklsid;
    }

    public void setJklsid(String jklsid) {
        this.jklsid = jklsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getJkid() {
        return jkid;
    }

    public void setJkid(String jkid) {
        this.jkid = jkid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJklx() {
        return jklx;
    }

    public void setJklx(String jklx) {
        this.jklx = jklx;
    }

    public String getAtzjkbz() {
        return atzjkbz;
    }

    public void setAtzjkbz(String atzjkbz) {
        this.atzjkbz = atzjkbz;
    }

    public String getAtnmjpfmbz() {
        return atnmjpfmbz;
    }

    public void setAtnmjpfmbz(String atnmjpfmbz) {
        this.atnmjpfmbz = atnmjpfmbz;
    }

    public Double getAtzje() {
        return atzje;
    }

    public void setAtzje(Double atzje) {
        this.atzje = atzje;
    }

    public Double getAtnmjpfje() {
        return atnmjpfje;
    }

    public void setAtnmjpfje(Double atnmjpfje) {
        this.atnmjpfje = atnmjpfje;
    }

    public Double getAtnmjzje() {
        return atnmjzje;
    }

    public void setAtnmjzje(Double atnmjzje) {
        this.atnmjzje = atnmjzje;
    }

    public Double getAjzmjpfje() {
        return ajzmjpfje;
    }

    public void setAjzmjpfje(Double ajzmjpfje) {
        this.ajzmjpfje = ajzmjpfje;
    }

    public Double getAjzmjzje() {
        return ajzmjzje;
    }

    public void setAjzmjzje(Double ajzmjzje) {
        this.ajzmjzje = ajzmjzje;
    }

    public String getAqtnr() {
        return aqtnr;
    }

    public void setAqtnr(String aqtnr) {
        this.aqtnr = aqtnr;
    }

    public Double getAqtnrpfje() {
        return aqtnrpfje;
    }

    public void setAqtnrpfje(Double aqtnrpfje) {
        this.aqtnrpfje = aqtnrpfje;
    }

    public Double getAqtnrzje() {
        return aqtnrzje;
    }

    public void setAqtnrzje(Double aqtnrzje) {
        this.aqtnrzje = aqtnrzje;
    }

    public String getZfdjbz() {
        return zfdjbz;
    }

    public void setZfdjbz(String zfdjbz) {
        this.zfdjbz = zfdjbz;
    }

    public Double getZfdjje() {
        return zfdjje;
    }

    public void setZfdjje(Double zfdjje) {
        this.zfdjje = zfdjje;
    }

    public String getDjyxx() {
        return djyxx;
    }

    public void setDjyxx(String djyxx) {
        this.djyxx = djyxx;
    }

    public String getXxspfjk() {
        return xxspfjk;
    }

    public void setXxspfjk(String xxspfjk) {
        this.xxspfjk = xxspfjk;
    }

    public String getFklx() {
        return fklx;
    }

    public void setFklx(String fklx) {
        this.fklx = fklx;
    }

    public Date getYcxfkjzrq() {
        return ycxfkjzrq;
    }

    public void setYcxfkjzrq(Date ycxfkjzrq) {
        this.ycxfkjzrq = ycxfkjzrq;
    }

    public Date getFqfkjzrq() {
        return fqfkjzrq;
    }

    public void setFqfkjzrq(Date fqfkjzrq) {
        this.fqfkjzrq = fqfkjzrq;
    }

    public Integer getFqfkqs() {
        return fqfkqs;
    }

    public void setFqfkqs(Integer fqfkqs) {
        this.fqfkqs = fqfkqs;
    }

    public String getSqfjkbz() {
        return sqfjkbz;
    }

    public void setSqfjkbz(String sqfjkbz) {
        this.sqfjkbz = sqfjkbz;
    }

    public Double getFqsqfjk() {
        return fqsqfjk;
    }

    public void setFqsqfjk(Double fqsqfjk) {
        this.fqsqfjk = fqsqfjk;
    }

    public Date getFqsqfjkjzrq() {
        return fqsqfjkjzrq;
    }

    public void setFqsqfjkjzrq(Date fqsqfjkjzrq) {
        this.fqsqfjkjzrq = fqsqfjkjzrq;
    }

    public String getDkfs() {
        return dkfs;
    }

    public void setDkfs(String dkfs) {
        this.dkfs = dkfs;
    }

    public Double getDksqfjk() {
        return dksqfjk;
    }

    public void setDksqfjk(Double dksqfjk) {
        this.dksqfjk = dksqfjk;
    }

    public Double getDksqfjkzb() {
        return dksqfjkzb;
    }

    public void setDksqfjkzb(Double dksqfjkzb) {
        this.dksqfjkzb = dksqfjkzb;
    }

    public String getYkbz() {
        return ykbz;
    }

    public void setYkbz(String ykbz) {
        this.ykbz = ykbz;
    }

    public Double getYkje() {
        return ykje;
    }

    public void setYkje(Double ykje) {
        this.ykje = ykje;
    }

    public String getFkqtfs() {
        return fkqtfs;
    }

    public void setFkqtfs(String fkqtfs) {
        this.fkqtfs = fkqtfs;
    }

    public String getYqclfs() {
        return yqclfs;
    }

    public void setYqclfs(String yqclfs) {
        this.yqclfs = yqclfs;
    }

    public Integer getYqxxrn() {
        return yqxxrn;
    }

    public void setYqxxrn(Integer yqxxrn) {
        this.yqxxrn = yqxxrn;
    }

    public Double getYqxrnwfzxwyj() {
        return yqxrnwfzxwyj;
    }

    public void setYqxrnwfzxwyj(Double yqxrnwfzxwyj) {
        this.yqxrnwfzxwyj = yqxrnwfzxwyj;
    }

    public Integer getYqcxxr() {
        return yqcxxr;
    }

    public void setYqcxxr(Integer yqcxxr) {
        this.yqcxxr = yqcxxr;
    }

    public Integer getJchthtsdrqxxr() {
        return jchthtsdrqxxr;
    }

    public void setJchthtsdrqxxr(Integer jchthtsdrqxxr) {
        this.jchthtsdrqxxr = jchthtsdrqxxr;
    }

    public Double getLjyfkxxbfb() {
        return ljyfkxxbfb;
    }

    public void setLjyfkxxbfb(Double ljyfkxxbfb) {
        this.ljyfkxxbfb = ljyfkxxbfb;
    }

    public Double getJchtwfzxwyj() {
        return jchtwfzxwyj;
    }

    public void setJchtwfzxwyj(Double jchtwfzxwyj) {
        this.jchtwfzxwyj = jchtwfzxwyj;
    }

    public String getYqqtfs() {
        return yqqtfs;
    }

    public void setYqqtfs(String yqqtfs) {
        this.yqqtfs = yqqtfs;
    }

    public String getAqtnrzjkbz() {
        return aqtnrzjkbz;
    }

    public void setAqtnrzjkbz(String aqtnrzjkbz) {
        this.aqtnrzjkbz = aqtnrzjkbz;
    }

    public String getAjzmjzjkbz() {
        return ajzmjzjkbz;
    }

    public void setAjzmjzjkbz(String ajzmjzjkbz) {
        this.ajzmjzjkbz = ajzmjzjkbz;
    }

    public String getAjzmjpfmbz() {
        return ajzmjpfmbz;
    }

    public void setAjzmjpfmbz(String ajzmjpfmbz) {
        this.ajzmjpfmbz = ajzmjpfmbz;
    }

    public String getAtnmjzjkbz() {
        return atnmjzjkbz;
    }

    public void setAtnmjzjkbz(String atnmjzjkbz) {
        this.atnmjzjkbz = atnmjzjkbz;
    }

    public Date getDksqfjzrq() {
        return dksqfjzrq;
    }

    public void setDksqfjzrq(Date dksqfjzrq) {
        this.dksqfjzrq = dksqfjzrq;
    }

    public String getDksqfjkbz() {
        return dksqfjkbz;
    }

    public void setDksqfjkbz(String dksqfjkbz) {
        this.dksqfjkbz = dksqfjkbz;
    }

    public String getKhyh() {
        return khyh;
    }

    public void setKhyh(String khyh) {
        this.khyh = khyh;
    }

    public String getYhzhm() {
        return yhzhm;
    }

    public void setYhzhm(String yhzhm) {
        this.yhzhm = yhzhm;
    }

    public String getYhzh() {
        return yhzh;
    }

    public void setYhzh(String yhzh) {
        this.yhzh = yhzh;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
